import { Module } from '@nestjs/common';
import { ConfigModule, ConfigService } from '@nestjs/config';
import configuration from './config/configuration';
import { TypeOrmModule } from '@nestjs/typeorm';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { UserModule } from './user/user.module';
import { GoodsModule } from './goods/goods.module';
import { OrderlogModule } from './orderlog/orderlog.module';
import { InvitedstatisticsModule } from './invitedstatistics/invitedstatistics.module';
import { ChickensModule } from './chickens/chickens.module';
import { ConfigurationModule } from './configuration/configuration.module';
import { AdminModule } from './admin/admin.module';
import logger from './common/utils/logger';
import { Log4jsModule } from '@nestx-log4js/core';


@Module({
  imports: [
    ConfigModule.forRoot({
      isGlobal: true,
      ignoreEnvFile: true,
      load: [configuration],
    }),
    Log4jsModule.forRootAsync({
      inject: [ConfigService],
      imports: [ConfigModule],
      useFactory: (config: ConfigService) => {
        return {
          config: logger,
        };
      },
    }),
    // RedisModule.forRootAsync({
    //   imports: [ConfigModule],
    //   useFactory: (configService: ConfigService) => {
    //     const nodes = configService.get('redis.cluster.nodes');
    //     if (nodes) {
    //       console.log('redis集群模式');
    //       return {
    //         nodes: nodes,
    //       };
    //     } else {
    //       console.log('redis普通模式');
    //       return {
    //         host: configService.get('redis.host'),
    //         port: configService.get('redis.port'),
    //         password: configService.get('redis.password', undefined),
    //       };
    //     }
    //   }, // or use async method
    //   inject: [ConfigService],
    // }),
    TypeOrmModule.forRootAsync({
      imports: [ConfigModule],
      inject: [ConfigService],
      useFactory: (
        configService: ConfigService,
      ) => ({
        name: 'default',
        type: 'mysql',
        host: configService.get('database.host'),
        port: configService.get('database.port'),
        username: configService.get('database.username'),
        password: configService.get('database.password'),
        database: configService.get('database.dbname'),
        synchronize: configService.get<boolean>('database.synchronize'),
        logging: configService.get('database.logging'),
        dropSchema: configService.get('database.drop_schema'),
        charset: configService.get<string>('database.charset'),
        entityPrefix: 'ck_',
        entities: ['dist/**/*.entity{.ts,.js}'],
        migrations: ['dist/**/*.migration{.ts,.js}'],
        subscribers: ['dist/**/*.subscriber{.ts,.js}'],
      }),
    }),
    AdminModule,
    UserModule,
    GoodsModule,
    OrderlogModule,
    InvitedstatisticsModule,
    ChickensModule,
    ConfigurationModule,
  ],
  controllers: [AppController],
  providers: [AppService, ConfigService],
})
export class AppModule { }
