/**
 *  访问外部API接口
 */

import { Logger } from "@nestjs/common";
import { AppUserModel } from "src/user/user.model";
import { CODE } from "../code";
import { httpGetRequest } from "./http-utils";
import { CustomResult, SuccessResult } from "./result-utils";

export class ExternalApiService {
    static logger = new Logger('ExternalApiService');

    /**获取APP用户信息 */
    static async getAppUserInfo(uid: number, token: string): Promise<AppUserModel | any> {
        try {
            const res = await httpGetRequest('Appapi/cash/getuser', { uid: uid, token: token });
            if (res.code == 0) {
                const data = res.info;
                const user = {
                    id: data.id,
                    nickname: data.user_nicename,
                    avatar: data.avatar,
                    sex: data.sex,
                    mobile: data.mobile,
                    coin: data.coin,
                    level: data.level,
                    risk: data.risk
                }
                return SuccessResult(user);
            }
            if (res?.code == 700) return CustomResult(CODE.CODE_APP_SERVER_TOKEN_ERR);
            this.logger.debug(`获取APP用户信息失败,app返回结果: ${JSON.stringify(res)}`);
            return CustomResult(CODE.CODE_APPUSER_INFO_ERR);
        } catch (e) {
            this.logger.debug(`调用APP接口异常: ${JSON.stringify(e)}`);
            return CustomResult(CODE.CODE_APP_SERVER_API_ERR);
        }
    }

    /**APP用户金额扣减 */
    static async subAppUserCoin(uid: number, token: string, value: number): Promise<AppUserModel | any> {
        try {
            const subRes = await httpGetRequest('Appapi/cash/getuser', { uid: uid, token: token, amount: -1 * value });
            this.logger.debug(`扣减用户信息返回结果:${JSON.stringify(subRes)}`);
            if (subRes.code == 0) {
                const data = subRes.info;
                const user = {
                    id: data.id,
                    nickname: data.user_nicename,
                    avatar: data.avatar,
                    sex: data.sex,
                    mobile: data.mobile,
                    coin: data.coin,
                    level: data.level,
                    risk: data.risk
                }
                return SuccessResult(user);
            }
            if (subRes?.code == 700) return CustomResult(CODE.CODE_APP_SERVER_TOKEN_ERR);
            this.logger.debug(`扣减用户APP余额失败,app返回结果: ${JSON.stringify(subRes)}`);
            return CustomResult(CODE.CODE_APPUSER_SUB_COIN_ERR);
        } catch (e) {
            this.logger.debug(`调用APP接口异常: ${JSON.stringify(e)}`);
            return CustomResult(CODE.CODE_APP_SERVER_API_ERR);
        }
    }


}