import { GoodsStatus, GoodsTypes } from "src/common/const";
import { Column, CreateDateColumn, Entity, PrimaryGeneratedColumn, UpdateDateColumn } from "typeorm";

/**商城商品主体 */
@Entity('goods')
export class GoodsEntity {
    @PrimaryGeneratedColumn()
    id?: number;

    @Column({
        comment: '商品类型(fodder-饲料;backdrop-背景;prop-道具;suit-套装)',
        type: "enum",
        enum: GoodsTypes,
        default: GoodsTypes.FODDER
    })
    type: string;

    @Column({ comment: '商品名', type: 'varchar', default: '' })
    name: string;

    @Column({ comment: '商品描述', type: 'varchar', default: '' })
    desc: string;

    @Column({ comment: '商品图片', type: 'varchar', default: '' })
    image: string;

    @Column({ comment: '价格', type: 'bigint' })
    price: number;

    @Column({ comment: '属性(如:饲料(克),背景/道具/套装(天)', type: 'bigint' })
    attribute: number;

    @Column({
        comment: '商品状态(selling-售卖中;sellend-售卖结束;hide-隐藏)',
        type: "enum",
        enum: GoodsStatus,
        default: GoodsStatus.HIDE
    })
    status: string;

    @CreateDateColumn({ comment: '创建时间', type: 'timestamp' })
    create_time: Date;

    @UpdateDateColumn({ comment: '修改时间', type: 'timestamp' })
    update_time: Date;
}
