import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { CODE } from 'src/common/code';
import { GoodsStatus, GoodsTypes } from 'src/common/const';
import { CustomResult, DataListResult, SuccessResult } from 'src/common/utils/result-utils';
import { Repository } from 'typeorm';
import { CreateGoodDto } from './dto/create-good.dto';
import { UpdateGoodDto } from './dto/update-good.dto';
import { GoodsEntity } from './entities/good.entity';
import { GoodsListModel } from './goods.model';

const prefix = 'goods';
@Injectable()
export class GoodsService {
  constructor(
    @InjectRepository(GoodsEntity)
    private readonly goodsRepository: Repository<GoodsEntity>,
  ) { }

  /**插入数据 */
  async create(createGoodDto: CreateGoodDto) {
    createGoodDto.type = createGoodDto.type || GoodsTypes.FODDER;
    createGoodDto.create_time = new Date();
    createGoodDto.update_time = new Date();
    const res = await this.goodsRepository.save(createGoodDto);
    if (!res) return CustomResult(CODE.CODE_GOODS_INSERT_ERR);
    return SuccessResult(res);
  }

  /** 查询所有-列表 */
  async goodsList(params: GoodsListModel) {
    let findBuilder = this.goodsRepository.createQueryBuilder(prefix);
    const limit = (params.pageIndex - 1 > 0 ? params.pageIndex - 1 : 0) * params.pageSize;
    //商品状态(API接口排除隐藏的)
    if (params.status) findBuilder = findBuilder.andWhere(`status != :status`, { status: params.status });
    const res = await findBuilder
      .select().skip(limit).take(params.pageSize).getRawMany();
    const total = await findBuilder.select().getCount();
    return DataListResult(res, params.pageIndex, params.pageSize, total);
  }

  /** 查询商品详情 */
  async findOne(id: number, status?: string) {
    let findBuilder = this.goodsRepository.createQueryBuilder(prefix);
    //商品状态(API接口排除隐藏的)
    if (status) findBuilder = findBuilder.andWhere(`status != :status`, { status: status });
    const returnData = await findBuilder.select().andWhere(`id=:id`, { id: id }).getRawOne();
    if (!returnData) return CustomResult(CODE.CODE_GOODS_INFO_ERR);
    return SuccessResult(returnData);
  }

  /** 商品更新 */
  async updateGoods(id: number, updateGoodDto: UpdateGoodDto) {
    updateGoodDto.update_time = new Date();
    const res = await this.goodsRepository.createQueryBuilder()
      .update()
      .set(updateGoodDto)
      .where('id = :id', { id: id })
      .execute();
    if (!res) return CustomResult(CODE.CODE_GOODS_UPDATE_ERR)
    return SuccessResult();
  }

  /** 商品删除 */
  async remove(id: number) {
    const res = await this.goodsRepository.createQueryBuilder()
      .delete()
      .where('id = :id', { id: id })
      .execute();
    if (!res || res.raw.affectedRows == 0) return CustomResult(CODE.CODE_GOODS_DELETE_ERR);
    return SuccessResult();
  }

  /** API 查询所有-列表 */
  async apiGoodsList(params: GoodsListModel) {
    let findBuilder = this.goodsRepository.createQueryBuilder(prefix);
    // const limit = (params.pageIndex - 1 > 0 ? params.pageIndex - 1 : 0) * params.pageSize;
    //商品状态(API接口排除隐藏的)
    const res = await findBuilder
      .select()
      .andWhere(`status != :status AND type = :type`, { status: GoodsStatus.HIDE, type: params.type })
      .getRawMany();
    // const total = await findBuilder.select().getCount();
    return res;
  }
}
